//
// MyCompanyNotifications.java
//
// This class is a TeamCity plug-in for extending the Freemarker root model so
// that we can incorporate the mycompanybuild.html file as part of the email we
// send out.
//
// We tried using the Freemarker <#include> item, but as of TeamCity 8 it is
// restricted to including files in the notifications template directory and
// cannot access artifact files.
//
// The TeamCity Freemarker files for email are located on the server in the
// directory:
//
//	D:\ProgramData\JetBrains\TeamCity\config\_notifications\email
//
// To use this, modify the .ftl file(s) to contain this line:
//
//	${mycompanynotifications.getFileContents( build.artifactsDirectory + "\\mycompanybuild.html" )}
//

package mycompany.teamcity.plugins;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.FileInputStream;
import java.lang.Exception;
import java.lang.StringBuilder;
import java.util.HashMap;
import java.util.Map;
import jetbrains.buildServer.notification.NotificationContext;
import jetbrains.buildServer.notification.TemplateProcessor;
//import jetbrains.buildServer.serverSide.SBuildServer;
import org.jetbrains.annotations.NotNull;
//import freemarker.ext.beans.BeansWrapper;

public class MyCompanyNotifications implements TemplateProcessor
{
	public static class MyCompanyReadFile
	{
		public String getFileContents( String fileName )
		{
			try
			{
				BufferedReader reader = new BufferedReader( new InputStreamReader( new FileInputStream( fileName ), "UTF-16" ) );
				String line = null;
				StringBuilder  stringBuilder = new StringBuilder();
				String ls = System.getProperty( "line.separator" );
				
				while( ( line = reader.readLine() ) != null )
				{
					stringBuilder.append( line );
					stringBuilder.append( ls );
				}
				
				return stringBuilder.toString();
			}
			catch( Exception e )
			{
				return "Can't read " + fileName;
			}
		}
	}
	
	@NotNull
	public Map< String, Object > fillModel( @NotNull NotificationContext context )
	{
		Map< String, Object > model = new HashMap< String, Object >();
		MyCompanyReadFile fileReader = new MyCompanyReadFile();
		model.put( "mycompanynotifications", fileReader );
		return model;
	}
}
